@@ -1,5 +1,5 @@
 DEBUG = 0
 INFO = 1
-WARN = 2
+WARNING = 2
 ERROR = 3
-FATAL = 4
+CRITICAL = 4
